# mergecraft 🚀

`mergecraft` is a command-line tool to merge files into a temporary file and open in VS Code.

![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)

python -m venv env
# ou se python não funcionar, tente python3
# python3 -m venv env

source env/Scripts/activate

pip install -r requirements.txt

.\env\Scripts\Activate.ps1


deactivate

choco install poppler

Instalar o Projeto Localmente:
Instale o seu projeto localmente usando o setup.py:
Copy code
pip install .

Usar o Comando mergecraft:
Depois de instalar o projeto, você pode usar o comando mergecraft em qualquer lugar do seu sistema:
css
Copy code
mergecraft [argumentos]